import requests
from scrapper.data_scrapper import DataScrapper

class SupremeCourtUnitedStates(DataScrapper):
    def __init__(self,source:str, area:str):
        super().__init__(source)
        self.area:str = area

    def get_data(self, output_path:str, format:str='json', save_data_on_file:bool=False):
        completed_url:str = self.source+self.area
        headers = {
          'Content-Type': 'application/json'
        }   

        response = requests.request("GET", completed_url, headers=headers, data={}).json()

        if(save_data_on_file):
          super()._save_data(self.area, response, format, output_path)

        return 'Data was saved! on {}'.format(output_path) if save_data_on_file else response

    def get_areas(self):
        completed_url:str = self.source
        headers = {
          'Content-Type': 'application/json'
        }   
        return requests.request("GET", completed_url, headers=headers, data={}).json()


import configparser
from typing import List
import pandas as pd
import json
from models.abstract import Abstract
from models.article import Article
from models.background import Background
from models.dictum import Dictum
from models.header import Header

from models.magistrate import Magistrate

config = configparser.ConfigParser()
config.read("config.ini")

class DataScrapper:
    def __init__(self, source) -> None:
        self.source:str = {section: dict(config.items(section)) for section in config.sections()}['URLS'][source.lower()]
        self.magistrates:list[Magistrate] = []
        self.backgrounds:list[Background] = []
        self.articles:list[Article] = []
        self.headers:list[Header] = []
        self.dictums:list[Dictum] = []
        self.abstracts:list[Abstract] = []

    def get_scrapper_sources(self):
        return {section: dict(config.items(section)) for section in config.sections()}['URLS']

    def _save_data(self, file_name:str, data, format:str, output_path:str):
      if format == 'json':
        formatted_output_path:str = '{}{}.{}'.format(output_path, file_name, format)
        with open(formatted_output_path, 'w') as outfile:
          json.dump(data, outfile)
      if format == 'graph': 
        case_ref = data['REFERENCIA_BOE']
        for elem in data['RESOLUCIONES_MAGISTRADOS']:
          self.magistrates.append(Magistrate(case_ref,elem))
        for elem in data['RESOLUCIONES_ANTECEDENTES']:
          self.backgrounds.append(Background(case_ref,elem))
        for elem in data['RESOLUCIONES_ARTICULOS']:
          self.articles.append(Article(case_ref,elem))
        for elem in data['RESOLUCIONES_CABECERA']:
          self.headers.append(Header(case_ref,elem))
        for elem in data['RESOLUCIONES_DICTAMEN']:
          self.dictums.append(Dictum(case_ref,elem))
        for elem in data['RESOLUCIONES_EXTRACTOS']:
          self.abstracts.append(Abstract(case_ref,elem))


from typing import List
import requests
import json
import pandas as pd
from scrapper.data_scrapper import DataScrapper

class SupremeCourtSpain(DataScrapper):
    def __init__(self,source:str, case_ids:List[str]):
        super().__init__(source)
        self.case_ids:List = case_ids

    def prepare_csv(self,output_path:str):
      magistrates_json = json.loads(json.dumps([ob.__dict__ for ob in self.magistrates]))
      pd.DataFrame.from_records(magistrates_json).to_csv(output_path+'magistrates.csv',index=False)
      backgrounds_json = json.loads(json.dumps([ob.__dict__ for ob in self.backgrounds]))
      pd.DataFrame.from_records(backgrounds_json).to_csv(output_path+'backgrounds.csv',index=False)
      articles_json = json.loads(json.dumps([ob.__dict__ for ob in self.articles]))
      pd.DataFrame.from_records(articles_json).to_csv(output_path+'articles.csv',index=False)
      headers_json = json.loads(json.dumps([ob.__dict__ for ob in self.headers]))
      pd.DataFrame.from_records(headers_json).to_csv(output_path+'headers.csv',index=False)
      dictums_json = json.loads(json.dumps([ob.__dict__ for ob in self.dictums]))
      pd.DataFrame.from_records(dictums_json).to_csv(output_path+'dictums.csv',index=False)
      abstracts_json = json.loads(json.dumps([ob.__dict__ for ob in self.abstracts]))
      pd.DataFrame.from_records(abstracts_json).to_csv(output_path+'abstracts.csv',index=False)

    def get_data(self, output_path:str, format:str='json', save_data_on_file:bool=False):
      completed_response = []
      for index,case_id in enumerate(self.case_ids):
        completed_url:str = self.source+case_id
        headers = {
          'Content-Type': 'application/json'
        }

        response = requests.request("GET", completed_url, headers=headers, data={}).json()

        if(save_data_on_file):
          super()._save_data(response['REFERENCIA_BOE'], response, format, output_path)
        else:
          completed_response.append(response)

        if (int(index) % 100 == 0):
          print('Number of scrapped elements: '+case_id)

      if(format == 'graph'):
        self.prepare_csv(output_path)

      return completed_response if len(completed_response)>0 else 'Data was saved! on {}'.format(output_path)